@@ -27,11 +27,19 @@ from ft_structs import *
 import ctypes.util
 
 
+__dll__    = None
+__handle__ = None
 FT_Library_filename = ctypes.util.find_library('freetype')
 if not FT_Library_filename:
+    try:
+        __dll__ = ctypes.CDLL('libfreetype.so.6')
+    except OSError:
+        __dll__ = None
+if not FT_Library_filename and not __dll__:
     raise RuntimeError, 'Freetype library not found'
-__dll__ = ctypes.CDLL(FT_Library_filename)
-__handle__ = None
+if not __dll__:
+  __dll__ = ctypes.CDLL(FT_Library_filename)
+
 
 
 # -----------------------------------------------------------------------------
@@ -88,7 +96,8 @@ FT_New_Memory_Face     = __dll__.FT_New_Memory_Face
 FT_Open_Face           = __dll__.FT_Open_Face
 FT_Attach_File         = __dll__.FT_Attach_File
 FT_Attach_Stream       = __dll__.FT_Attach_Stream
-FT_Reference_Face      = __dll__.FT_Reference_Face
+if version()>=(2,4,2):
+    FT_Reference_Face      = __dll__.FT_Reference_Face
 FT_Done_Face           = __dll__.FT_Done_Face
 FT_Done_Glyph          = __dll__.FT_Done_Glyph
 FT_Select_Size         = __dll__.FT_Select_Size
@@ -118,7 +127,8 @@ FT_Get_First_Char      = __dll__.FT_Get_First_Char
 FT_Get_Next_Char       = __dll__.FT_Get_Next_Char
 FT_Get_Name_Index      = __dll__.FT_Get_Name_Index
 FT_Get_SubGlyph_Info   = __dll__.FT_Get_SubGlyph_Info
-FT_Get_FSType_Flags    = __dll__.FT_Get_FSType_Flags
+if version()>=(2,3,8):
+    FT_Get_FSType_Flags    = __dll__.FT_Get_FSType_Flags
 FT_Get_Sfnt_Name_Count = __dll__.FT_Get_Sfnt_Name_Count
 FT_Get_Sfnt_Name       = __dll__.FT_Get_Sfnt_Name
 
@@ -974,6 +984,7 @@ class Face( object ):
         '''
         library = get_handle( )
         face = FT_Face( )
+        self._FT_Face = None
         error = FT_New_Face( library, filename, 0, byref(face) )
         if error: raise FT_Exception( error )
         self._filename = filename
@@ -984,7 +995,8 @@ class Face( object ):
         '''
         Discard  face object, as well as all of its child slots and sizes.
         '''
-        FT_Done_Face( self._FT_Face )
+        if self._FT_Face is not None:
+            FT_Done_Face( self._FT_Face )
 
     def set_char_size( self, width=0, height=0, hres=72, vres=72 ):
         '''
@@ -1075,7 +1087,7 @@ class Face( object ):
         correspond to the internal indices used within the file. This is done
         to ensure that value 0 always corresponds to the 'missing glyph'.
         '''
-        if type( charcode ) is str:
+        if type( charcode ) in (str,unicode):
             charcode = ord( charcode )
         return FT_Get_Char_Index( self._FT_Face, charcode )
 
